#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor testsuite%{nil}
%if "%{?flavor}" != "" && "%{?flavor}" != ("@BUILD_" + "FLAVOR@")
%define name_suffix -%{flavor}
%else
%define name_suffix %{nil}
%endif

%define pversion 5.38.2
# set to nil when equal to pversion
%global versionlist 5.38.0
Name:           perl%{?name_suffix}
Version:        5.38.2
Release:        1.2
Summary:        The Perl interpreter
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Languages/Perl
URL:            https://www.perl.org/
Source:         https://www.cpan.org/src/5.0/perl-%{version}.tar.xz
Source1:        perl-rpmlintrc
Source2:        macros.perl
Source3:        README.macros
Source4:        baselibs.conf
Patch0:         perl-5.38.0.diff
Patch3:         perl-nroff.diff
Patch4:         perl-netcmdutf8.diff
Patch5:         perl-HiRes.t-timeout.diff
Patch6:         perl-saverecontext.diff
# PATCH-FIX-OPENSUSE perl-5.22.0_wrong_rpm_provides.diff Prevent generating bad RPM provides
Patch7:         perl-5.22.0_wrong_rpm_provides.diff
Patch8:         skip_time_hires.patch
Patch9:         perl-incfix.diff
Patch11:        perl-5.18.2-overflow.diff
# PATCH-FIX-OPENSUSE prevent changing package when rebuilding
Patch12:        perl-reproducible.patch
# PATCH-FIX-OPENSUSE skip flaky tests powerpc as bypass https://bugzilla.suse.com/show_bug.cgi?id=1063176
Patch13:        perl_skip_flaky_tests_powerpc.patch
# PATCH-FIX-UPSTREAM unmerged https://www.nntp.perl.org/group/perl.perl5.porters/2018/12/msg253240.html
Patch18:        perl-reproducible2.patch
BuildRequires:  db-devel
BuildRequires:  gdbm-devel
BuildRequires:  libbz2-devel
BuildRequires:  ncurses-devel
# For t/op/magic and dist/threads/t/join - but because perl is a bootstrap package don't use it
#BuildRequires:  procps
BuildRequires:  xz
BuildRequires:  zlib-devel
Requires:       perl-base = %{version}
Suggests:       perl-doc = %{version}
Provides:       perl-500
Provides:       perl-Archive-Tar = 2.40
Provides:       perl(:MODULE_COMPAT_%{pversion})
%if "%{versionlist}" != ""
Provides:       perl(:MODULE_COMPAT_%{versionlist})
%endif
Obsoletes:      perl-Archive-Tar <= 2.40
Provides:       perl-autodie = 2.36
Obsoletes:      perl-autodie <= 2.36
Provides:       perl-Compress-Raw-Zlib = 2.204
Obsoletes:      perl-Compress-Raw-Zlib <= 2.204
Provides:       perl-Compress-Zlib = 2.204
Obsoletes:      perl-Compress-Zlib <= 2.204
Provides:       perl-CPAN-Meta = 2.150010
Obsoletes:      perl-CPAN-Meta <= 2.150010
Provides:       perl-CPAN-Meta-YAML = 0.018
Obsoletes:      perl-CPAN-Meta-YAML <= 0.018
Provides:       perl-ExtUtils-CBuilder = 0.280238
Obsoletes:      perl-ExtUtils-CBuilder <= 0.280238
Provides:       perl-ExtUtils-ParseXS = 3.51
Obsoletes:      perl-ExtUtils-ParseXS <= 3.51
Provides:       perl-Filter-Simple = 0.96
Obsoletes:      perl-Filter-Simple <= 0.96
Provides:       perl-I18N-LangTags = 0.45
Obsoletes:      perl-I18N-LangTags <= 0.45
Provides:       perl-IO-Compress-Base = 2.204
Obsoletes:      perl-IO-Compress-Base <= 2.204
Provides:       perl-IO-Compress-Zlib = 2.204
Obsoletes:      perl-IO-Compress-Zlib <= 2.204
Provides:       perl-IO-Socket-IP = 0.41
Obsoletes:      perl-IO-Socket-IP <= 0.41
Provides:       perl-IO-Zlib = 1.14
Obsoletes:      perl-IO-Zlib <= 1.14
Provides:       perl-libnet = 3.15
Obsoletes:      perl-libnet <= 3.15
Provides:       perl-Locale-Maketext-Simple = 0.21
Obsoletes:      perl-Locale-Maketext-Simple <= 0.21
Provides:       perl-MIME-Base64 = 3.16
Obsoletes:      perl-MIME-Base64 <= 3.16
Provides:       perl-Parse-CPAN-Meta = 2.150010
Obsoletes:      perl-Parse-CPAN-Meta <= 2.150010
Provides:       perl-PathTools = 3.88
Obsoletes:      perl-PathTools <= 3.88
Provides:       perl-Pod-Escapes = 1.07
Obsoletes:      perl-Pod-Escapes <= 1.07
Provides:       perl-Pod-Simple = 3.43
Obsoletes:      perl-Pod-Simple <= 3.43
Provides:       perl-Storable = 3.32
Obsoletes:      perl-Storable <= 3.32
Provides:       perl-Test-Harness = 3.44
Obsoletes:      perl-Test-Harness <= 3.44
Provides:       perl-Test-Simple = 1.302194
Obsoletes:      perl-Test-Simple <= 1.302194
Provides:       perl-Text-Balanced = 2.06
Obsoletes:      perl-Text-Balanced <= 2.06
Provides:       perl-Time-HiRes = 1.9775
Obsoletes:      perl-Time-HiRes <= 1.9775
Provides:       perl-version = 0.9929
Obsoletes:      perl-version <= 0.9929
%if "%{version}" != "%{pversion}"
Provides:       perl = %{pversion}-%{release}
%endif

%description
perl - Practical Extraction and Report Language

Perl is optimized for scanning arbitrary text files, extracting
information from those text files, and printing reports based on that
information.  It is also good for many system management tasks. Perl is
intended to be practical (easy to use, efficient, and complete) rather
than beautiful (tiny, elegant, and minimal).

Some of the modules available on CPAN can be found in the "perl"
series.

%package base
Summary:        The Perl interpreter
Group:          Development/Languages/Perl
Provides:       perl-Digest
Provides:       perl-Digest-MD5 = 2.55
%if "%{version}" != "%{pversion}"
Provides:       perl-base = %{pversion}-%{release}
%endif

%description base
perl - Practical Extraction and Report Language

Perl is optimized for scanning arbitrary text files, extracting
information from those text files, and printing reports based on that
information.  It is also good for many system management tasks.

Perl is intended to be practical (easy to use, efficient, and complete)
rather than beautiful (tiny, elegant, and minimal).

This package contains only some basic modules and the perl binary
itself.

%package doc
Summary:        Perl Documentation
Group:          Development/Languages/Perl
Requires:       perl = %{version}
Provides:       perl-macros = 2.0
Provides:       perl:%{_mandir}/man3/CORE.3pm.gz
Obsoletes:      perl-macros < 2.0
BuildArch:      noarch

%description doc
Perl man pages and pod files.

%prep
%setup -q -n perl-%{pversion}
cp -p %{SOURCE3} .
%patch0
%patch3
%patch4
%patch5
%patch6
%patch7
%ifarch ppc ppc64 ppc64le
%patch8 -p1
%patch13
%endif
%patch9 -p1
%patch11
%patch12 -p1
%patch18

%build
%define _lto_cflags %{nil}
cp -a lib savelib
export BZIP2_LIB=%{_libdir}
export BZIP2_INCLUDE=%{_includedir}
export BUILD_BZIP2=0
options="-Doptimize='%{optflags} -Wall -pipe'"
%ifarch alpha
# -mieee needed for bad alpha gcc optimization
options="-Doptimize='%{optflags} -Wall -pipe -mieee'"
%endif
# Use 64-bit integers everywhere
options="$options -Duse64bitint"
# this needs an installed perl, sorry
archname=%(perl -V:archname | sed "s!.*='!!;s!'.*!!")
test -n "$archname"
versionlist=
for v in %{?versionlist} ; do
  test "$v" == none || versionlist="$versionlist $v/$archname $v"
done
test -n "$versionlist" || versionlist=none
versionlist=${versionlist# }
options="$options -Dotherlibdirs=/usr/lib/perl5/site_perl -Dinc_version_list='$versionlist'"
chmod 755 ./configure.gnu
./configure.gnu --prefix=%{_prefix} -Dvendorprefix=%{_prefix} -Dinstallusrbinperl -Dusethreads -Di_db -Di_dbm -Di_ndbm -Di_gdbm -Dd_dbm_open -Duseshrplib=\'true\' $options
make %{?_smp_mflags}
cp -p libperl.so savelibperl.so
cp -p lib/Config.pm saveConfig.pm
cp -p lib/Config_heavy.pl saveConfig_heavy.pl
make -j1 clobber
rm -rf lib
mv savelib lib
./configure.gnu --prefix=%{_prefix} -Dvendorprefix=%{_prefix} -Dinstallusrbinperl -Dusethreads -Di_db -Di_dbm -Di_ndbm -Di_gdbm -Dd_dbm_open $options
make %{?_smp_mflags}

%check
%if 0%{?qemu_user_space_build}
# Disable tests that are difficult to emulate
echo 'print "1..0\n";' > t/op/fork.t
echo 'print "1..0\n";' > t/op/magic.t
%endif
%if "%{name}" == "perl-testsuite"
TEST_JOBS="%{jobs}" make %{?_smp_mflags} test
%endif

%install
%if "%{name}" != "perl-testsuite"
%make_install
cp -a %{buildroot}/usr/lib/perl5/site_perl %{buildroot}/usr/lib/perl5/vendor_perl
cpa=`echo %{buildroot}/usr/lib/perl5/*/*/CORE | sed -e 's@/CORE$@@'`
cp=`echo "$cpa" | sed -e 's@/[^/]*$@@'`
vpa=`echo $cpa | sed -e 's@/perl5/@/perl5/vendor_perl/@'`
vp=`echo "$vpa" | sed -e 's@/[^/]*$@@'`
install -d $vp/auto
install -d $vpa/auto
install -m 555 savelibperl.so $cpa/CORE/libperl.so
install -m 444 saveConfig.pm $cpa/Config.pm
install -m 444 saveConfig_heavy.pl $cpa/Config_heavy.pl
# install macros.perl file
install -D -m 644 %{SOURCE2} %{buildroot}%{_rpmconfigdir}/macros.d/macros.perl
pushd %{_includedir}
( rpm -ql glibc-devel | grep -F '.h'
  find %{_includedir}/asm/ -name \*.h
  find %{_includedir}/asm-generic -name \*.h
  find %{_includedir}/linux -name \*.h
) | while read f; do
  %{buildroot}%{_bindir}/perl -I$cp -I$cpa %{buildroot}%{_bindir}/h2ph -d $vpa ${f/\/usr\/include\//} || :
done
popd
d="`gcc -print-file-name=include`"
test -f "$d/stdarg.h" && (cd $d ; %{buildroot}%{_bindir}/perl -I$cp -I$cpa %{buildroot}%{_bindir}/h2ph -d $vpa stdarg.h stddef.h float.h)
# remove broken pm - we don't have the module
rm -f %{buildroot}/usr/lib/perl5/*/Pod/Perldoc/ToTk.pm
# we don't need this in here
rm -f %{buildroot}/usr/lib/perl5/*/*/CORE/libperl.a
# test CVE-2007-5116
%{buildroot}%{_bindir}/perl -e '$r=chr(128)."\\x{100}";/$r/'
# test perl-regexp-refoverflow.diff, should not crash or hang
%{buildroot}%{_bindir}/perl -e 'eval "/\\6666666666/"'
cat << EOF > perl-base-filelist
/usr/lib/perl5/%{pversion}/B/Deparse.pm
/usr/lib/perl5/%{pversion}/Carp.pm
/usr/lib/perl5/%{pversion}/Carp/
/usr/lib/perl5/%{pversion}/Class/
/usr/lib/perl5/%{pversion}/Config/
/usr/lib/perl5/%{pversion}/Digest.pm
/usr/lib/perl5/%{pversion}/Digest/
/usr/lib/perl5/%{pversion}/English.pm
/usr/lib/perl5/%{pversion}/Exporter.pm
/usr/lib/perl5/%{pversion}/Exporter/
/usr/lib/perl5/%{pversion}/File/
/usr/lib/perl5/%{pversion}/Getopt/
/usr/lib/perl5/%{pversion}/IPC/
/usr/lib/perl5/%{pversion}/Text/
/usr/lib/perl5/%{pversion}/Tie/Hash.pm
/usr/lib/perl5/%{pversion}/XSLoader.pm
/usr/lib/perl5/%{pversion}/warnings.pm
/usr/lib/perl5/%{pversion}/warnings/
/usr/lib/perl5/%{pversion}/AutoLoader.pm
/usr/lib/perl5/%{pversion}/FileHandle.pm
/usr/lib/perl5/%{pversion}/SelectSaver.pm
/usr/lib/perl5/%{pversion}/Symbol.pm
/usr/lib/perl5/%{pversion}/base.pm
/usr/lib/perl5/%{pversion}/builtin.pm
/usr/lib/perl5/%{pversion}/bytes.pm
/usr/lib/perl5/%{pversion}/bytes_heavy.pl
/usr/lib/perl5/%{pversion}/constant.pm
/usr/lib/perl5/%{pversion}/fields.pm
/usr/lib/perl5/%{pversion}/feature.pm
/usr/lib/perl5/%{pversion}/integer.pm
/usr/lib/perl5/%{pversion}/locale.pm
/usr/lib/perl5/%{pversion}/overload.pm
/usr/lib/perl5/%{pversion}/overloading.pm
/usr/lib/perl5/%{pversion}/parent.pm
/usr/lib/perl5/%{pversion}/strict.pm
/usr/lib/perl5/%{pversion}/utf8.pm
/usr/lib/perl5/%{pversion}/vars.pm
/usr/lib/perl5/%{pversion}/version.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/Data/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/Digest/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/File/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/List/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/Scalar/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO/Dir.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO/File.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO/Handle.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO/Pipe.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO/Poll.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO/Seekable.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO/Select.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO/Socket.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/IO/Socket/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/B.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/Config.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/Config_heavy.pl
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/Cwd.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/DynaLoader.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/Errno.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/Fcntl.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/POSIX.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/Socket.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/attributes.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/Data/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/Digest/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/Fcntl/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/File/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/IO/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/List/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/Cwd/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/Socket/
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/POSIX/POSIX.so
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/lib.pm
/usr/lib/perl5/%{pversion}/*-linux-thread-multi*/re.pm
EOF
{
  sed -e 's/^/%%exclude /' perl-base-filelist
  (cd %{buildroot}
   for i in usr/lib/perl5/*/pod/*; do
     case $i in */perldiag.pod) ;;
     *) echo "%%exclude /$i" ;;
     esac
   done)
} > perl-base-excludes
%endif

%if "%{name}" == "perl"
%files base -f perl-base-filelist
%license Copying Artistic
%dir /usr/lib/perl5
%dir /usr/lib/perl5/%{pversion}
%dir /usr/lib/perl5/%{pversion}/B
%dir /usr/lib/perl5/%{pversion}/*-linux-thread-multi*
%dir /usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto
%dir /usr/lib/perl5/%{pversion}/*-linux-thread-multi*/auto/POSIX
%{_bindir}/perl
%{_bindir}/perl%{pversion}
%{_mandir}/man1/perl.1%{?ext_man}

%files -f perl-base-excludes
%exclude %{_bindir}/perl
%exclude %{_bindir}/perl%{pversion}
%{_bindir}/*
/usr/lib/perl5/*
%{_rpmconfigdir}/macros.d/macros.perl

%files doc
%doc README.macros
%exclude %{_mandir}/man1/perl.1.gz
%exclude /usr/lib/perl5/*/pod/perldiag.pod
%{_mandir}/man1/*
%{_mandir}/man3/*
%doc /usr/lib/perl5/*/pod
%endif

%changelog
* Mon Nov 27 2023 mls@suse.de
- Update to perl 5.38.2
  * fixes [CVE-2023-47038] Write past buffer end via illegal
    user-defined Unicode property [bnc#1217084]
  * fixes [CVE-2023-47039] Perl for Windows binary hijacking
    vulnerability [bnc#1217085]
* Thu Sep 21 2023 Neal Gompa <ngompa@opensuse.org>
- Use 64-bit integers on all platforms
* Wed Jul 19 2023 mls@suse.de
- Update to perl 5.38.0
  * new "class" feature
  * support for unicode 15.0
  * defined-or and logical-or assignment default
    expressions in signatures
  * optimistic eval in patterns
  * readline() no longer clears the stream error and eof flags
  * "INIT" blocks no longer run after an "exit()" in "BEGIN"
  * utf8::upgrade() keeps the undef value
  * deprecation of ' as package name separator
  * deprecation of the smart match operator
  * PERL_USE_SAFE_PUTENV is now the default
- Rebase perl-5.36.0.diff to perl-5.38.0.diff
- Refresh perl_skip_flaky_tests_powerpc.patch
* Thu Jun  1 2023 Dirk Stoecker <opensuse@dstoecker.de>
- update to perl 5.36.1 - maintenance release
  * Module::CoreList has been upgraded from version 5.20220520 to 5.20230423.
  * Fixed: An eval() as the last statement in a regex code block could trigger
    an interpreter panic
  * An eval EXPR referring to a lexical sub defined in grandparent scope no
    longer produces an assertion failures.
  * Writing to a magic variables associated with the selected output handle,
    $^, $~, $=, $- and $%%, no longer crashes perl if the IO object has been
    cleared from the selected output handle.
* Wed Jan 11 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Replace usage of deprecated fgrep with grep -F.
* Mon Jul 25 2022 mls@suse.de
- fix build on ppc
  * updated patch: perl_skip_flaky_tests_powerpc.patch
* Fri Jul 15 2022 Adrian Schröter <adrian@suse.de>
- move builtin.pm to perl-base as File::Copy relies on it since last
  update.
  This fixes execution of builtime source services in OBS.
* Thu Jun 23 2022 mls@suse.de
- Update to 5.36.0
  * the signatures and isa features are no longer experimental and
    part of the v5.36 feature bundle
  * the v5.36 bundle also enables warnings
  * new '-g' command line flag (alias for -0777)
  * support for unicode 14.0
  * regex sets are no longer considered experimental
  * experimental iterating over multiple values at a time
  * experimental new builtin module
  * experimental defer blocks
  * try/catch can now have a finally block
  * experimental non-ASCII delimiters for quote-like operators
  * a physically empty sort is now a compile-time error
- Rebase perl-5.34.0.dif to perl-5.36.0.diff
- Refresh perl-5.18.2-overflow.diff
* Wed May  4 2022 Dirk Stoecker <opensuse@dstoecker.de>
- Update to 5.34.1 - maintenance release
  B::Deparse has been upgraded from version 1.56 to 1.57.
  Encode has been upgraded from version 3.08 to 3.08_01.
  GDBM_File has been upgraded from version 1.19 to 1.19_01.
  Module::CoreList has been upgraded from version 5.20210520 to 5.20220313.
  perl5db.pl has been upgraded from version 1.60 to 1.60_01.
- Drop c029d660f2fe60699cf64bbb3fa9f671a1a370d5.patch (upstream)
* Thu Mar  3 2022 Andreas Schwab <schwab@suse.de>
- Don't install anything in testsuite build
- Run testsuite also in qemu build
- posix-sigaction.patch: remove, this has been fixed properly in commit
  19c9c2ee4a
* Mon Oct  4 2021 Stephan Kulow <coolo@suse.com>
- Add multibuild flavor to split the testsuite out of the main package
  build time. The testsuite dominates the build time and having perl
  in the bootstrap cycle, we better seperate it. The testsuite flavor
  rebuilds the same package the same way, but runs the check section
* Thu Sep  2 2021 Dirk Stoecker <opensuse@dstoecker.de>
- update to 5.34.0
  * Experimental Try/Catch Syntax
  * Blanks freely allowed within but adjacent to curly braces
  * New octal syntax 0oddddd
  * Fix a memory leak in RegEx [GH #18604]
  * ExtUtils::PL2Bat 0.004 has been added to the Perl core.
  * Updated Modules and Pragmata
- Rebase perl-5.28.0.dif to perl-5.34.0.dif
- Rebase perl-incfix.diff
- Rebase perl_skip_flaky_tests_powerpc.patch
- Drop perl-gdbm-test-no-mmap.diff (no longer needed with gdbm 1.20)
- Add c029d660f2fe60699cf64bbb3fa9f671a1a370d5.patch to fix build with
  gdbm 1.20
- Drop perl-fix2020.patch (included upstream)
* Sun Mar 14 2021 Dirk Müller <dmueller@suse.com>
- update to 5.32.1:
    There are no changes intentionally incompatible with Perl 5.32.0.
  * Data::Dumper has been upgraded from version 2.174 to 2.174_01.
    A number of memory leaks have been fixed.
  * DynaLoader has been upgraded from version 1.47 to 1.47_01.
  * Module::CoreList has been upgraded from version 5.20200620 to
    5.20210123.
  * Opcode has been upgraded from version 1.47 to 1.48.
    A warning has been added about evaluating untrusted code with the
    perl interpreter.
  * Safe has been upgraded from version 2.41 to 2.41_01.
    A warning has been added about evaluating untrusted code with the
    perl interpreter.
* Fri Nov 13 2020 Dan Čermák <dcermak@suse.com>
- Correct perl license
  According to https://dev.perl.org/licenses/ perl is licensed under the
  artistic license or the GPL 1.0 or later
* Tue Oct 27 2020 mls@suse.de
- update to perl-5.32.0
  * new experimental infix "isa" operator
  * support of unicode 13.0
  * chained comparisons capability
- updated patches:
  * perl-HiRes.t-timeout.diff
  * posix-sigaction.patch
  * perl-fix2020.patch
  * perl-reproducible2.patch
  * perl_skip_flaky_tests_powerpc.patch
* Fri Sep 11 2020 Dirk Mueller <dmueller@suse.com>
- update to 5.30.3 (bsc#1171863, bsc#1171864, bsc#1171866):
  * https://perldoc.perl.org/5.30.3/perl5302delta.html
  * https://perldoc.perl.org/5.30.3/perldelta.html
  * fixes [CVE-2020-10543] buffer overflow caused by a crafted
    regular expression
  * fixes [CVE-2020-10878] integer overflow via malformed bytecode
    produced by a crafted regular expression
  * fixes [CVE-2020-12723] buffer overflow caused by a crafted
    regular expression
- dropped patches:
  * perl-Adapt-Configure-to-GCC-version-10.patch
* Wed Aug  5 2020 Thorsten Kukuk <kukuk@suse.com>
- Move macros.perl to /usr/lib/rpm/macros.d
* Fri Jun  5 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec
* Mon Dec  9 2019 Jan Baier <jbaier@suse.com>
- Fix incorrect prefix removal in rpm macro %%perl_gen_filelist (boo#1152247)
* Tue Dec  3 2019 Martin Liška <mliska@suse.cz>
- Add perl-Adapt-Configure-to-GCC-version-10.patch in order
  to fix boo#1158254.
* Tue Nov 19 2019 mls@suse.de
- update to perl-5.30.1
  * unicode 12.1 is supported
  * turkic UTF-8 locales are now seamlessly supported
  * assigning non-zero to $[ is fatal
  * some formerly deprecated uses of an unescaped left brace "{" in
    regular expression patterns are now illegal
  * previously deprecated sysread()/syswrite() on :utf8 handles is
    now fatal
  * my() in false conditional prohibited
  * remove File::Glob::glob()
  * various performance enhancements
- updated patches:
  * perl-5.22.0_wrong_rpm_provides.diff
  * perl-gdbm-test-no-mmap.diff
  * perl-fix2020.patch
  * perl-reproducible2.patch
- dropped patches:
  * perl-revert-caretx.diff
  * perl-regexp-refoverflow.diff
* Thu Jun 20 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1138837).
* Thu Jan 24 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add perl-fix2020.patch to fix timelocal calls in 2020 (boo#1102840)
- Add perl-reproducible2.patch to make build reproducible in spite of ASLR
* Fri Nov 30 2018 mls@suse.de
- update to perl-5.28.1
  * [CVE-2018-18311] Integer overflow leading to buffer overflow
  * [CVE-2018-18312] Heap-buffer-overflow write in S_regatom
  * updated Module::CoreList module
* Tue Oct  2 2018 mls@suse.de
- simplify perl_gen_filelist macro
* Fri Sep 28 2018 mls@suse.de
- fix testing fatal errors in gdbm
  new patch: perl-gdbm-test-no-mmap.diff
- fix perl no longer setting $^X if /proc is not mounted
  new patch: perl-revert-caretx.diff
* Wed Sep 26 2018 mls@suse.de
- change the perl_gen_filelist macro so that the modules no
  longer own the perl_vendorarch directory [bnc#1109754]
* Sat Sep 22 2018 Dirk Stoecker <opensuse@dstoecker.de>
- update to perl-5.28.0
  * Core Enhancements
  * Unicode 10.0 is supported
  * delete on key/value hash slices
  * Experimentally, there are now alphabetic synonyms for some regular expression assertions
  * Mixed Unicode scripts are now detectable
  * In-place editing with perl -i is now safer
  * Initialisation of aggregate state variables
  * Full-size inode numbers
  * The sprintf %%j format size modifier is now available with pre-C99 compilers
  * Close-on-exec flag set atomically
  * String- and number-specific bitwise ops are no longer experimental
  * Locales are now thread-safe on systems that support them
  * New read-only predefined variable ${^SAFE_LOCALES}
  * Security
  * [CVE-2017-12837] Heap buffer overflow in regular expression compiler
  * [CVE-2017-12883] Buffer over-read in regular expression parser
  * [CVE-2017-12814] $ENV{$key} stack buffer overflow on Windows
  * Default Hash Function Change
  * Full list of changes: https://metacpan.org/pod/release/XSAWYERX/perl-5.28.0/pod/perldelta.pod
- update perl-5.26.0.dif to perl-5.28.0.dif
- drop patch perl-pp-crypt.patch (included upstream)
* Tue Sep 18 2018 schwab@suse.de
- perl-pp-crypt.patch: fix incompatibility with libxcrypt (bsc#1107973)
* Wed May 23 2018 mls@suse.de
- make perl-5.26.2 compatible with perl-5.26.1
* Mon May 14 2018 tchvatal@suse.com
- Update versions based on provides in perl rpm
* Fri May 11 2018 tchvatal@suse.com
- Version update to perl-5.26.2:
  * Tons of bugfixes
* Fri May 11 2018 tchvatal@suse.com
- Remove the as-needed disabling as no other distro is doing that
- Use macros where possible
- Remove if0 and commented out code to reduce the scope
- Run tests in threads
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Mon Jan 22 2018 schwab@suse.de
- posix-sigaction.patch: make sure Perl_sighandler is always installed
  with SA_SIGINFO (bsc#1064697)
* Wed Jan 10 2018 normand@linux.vnet.ibm.com
- ignore make check transient errors for PowerPC
  that are reported since 20170907
  bypass boo#1063176
  new patch: perl_skip_flaky_tests_powerpc.patch
* Mon Dec  4 2017 bwiedemann@suse.com
- Add perl-reproducible.patch to make build reproducible (boo#1047218)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Sat Sep 23 2017 coolo@suse.com
- update to perl-5.26.1
  * [CVE-2017-12837] Heap buffer overflow in regular expression compiler
  * [CVE-2017-12883] Buffer over-read in regular expression parser
  * tons of bug fixes
- update list of obsoletes
* Wed Aug 30 2017 mls@suse.de
- update to perl-5.26.0
  * "." no longer in @INC
  * "do" may now warn
  * regexp: a literal left brace "{" should be escaped
  * lexical subroutines are no longer experimental
  * indented Here-documents
  * new regular expression modifier /xx
  * declaring a reference to a variable
  * unicode 9.0 is now supported
  * new Hash Function For 64-bit Builds
- rename perl-5.24.0.dif to perl-5.26.0.dif
- remove obsolete perl-avoid-warnings.patch
- remove obsolete Compress-Raw-Zlib-2.071-zlib-1.2.11.patch
* Thu May 18 2017 tchvatal@suse.com
- Remove patch from previous commit, does not work:
  * Compress-Raw-Zlib-2.071-Adapt-tests-to-zlib-1.2.11.patch
- Add patch taken from upstream release instead:
  * Compress-Raw-Zlib-2.071-zlib-1.2.11.patch
* Wed May 10 2017 mpluskal@suse.com
- Fix building with zlib-1.2.10 (RT#119762):
  * Compress-Raw-Zlib-2.071-Adapt-tests-to-zlib-1.2.11.patch
* Wed May  3 2017 coolo@suse.com
- Update to perl-5.24.1
  - Di switch is now required for PerlIO debugging output
    Previously PerlIO debugging output would be sent to the file specified
    by the "PERLIO_DEBUG" environment variable if perl wasn't running setuid
    and the -T or -t switches hadn't been parsed yet.
    If perl performed output at a point where it hadn't yet parsed its
    switches this could result in perl creating or overwriting the file
    named by "PERLIO_DEBUG" even when the -T switch had been supplied.
    Perl now requires the -Di switch to produce PerlIO debugging output. By
    default this is written to "stderr", but can optionally be redirected to
    a file by setting the "PERLIO_DEBUG" environment variable.
    If perl is running setuid or the -T switch was supplied "PERLIO_DEBUG"
    is ignored and the debugging output is sent to "stderr" as for any other
  - D switch.
  Core modules and tools no longer search "." for optional modules
    The tools and many modules supplied in core no longer search the default
    current directory entry in @INC for optional modules. For example,
    Storable will remove the final "." from @INC before trying to load
    Log::Agent.
    This prevents an attacker injecting an optional module into a process
    run by another user where the current directory is writable by the
    attacker, e.g. the /tmp directory.
- Refresh patches
* Sun Jun 26 2016 schwab@suse.de
- Move parent.pm to perl-base, used by File::Temp
* Thu Jun  2 2016 idonmez@suse.com
- Add perl-avoid-warnings.patch to fix a warning in cop.h, which
  breaks perf build due to -Werror. Already upstream.
* Tue May 10 2016 mls@suse.de
- Update to perl-5.24.0
  * postfix dereferencing is no longer experimental
  * unicode 8.0 is now supported
  * perl will now croak when closing an in-place output file fails
  * new "\b{lb}" boundary in regular expressions
  * qr/(?[ ])/" now works in UTF-8 locales
  * integer shift ("<<" and ">>") now more explicitly defined
  * printf and sprintf now allow reordered precision arguments
  * more fields provided to "sigaction" callback with "SA_SIGINFO"
  * hashbang redirection to Perl 6
  * set proper umask before calling mkstemp(3)
  * fix loss of taint in canonpath
  * remove duplicate environment variables from "environ"
- rename patch perl-5.22.0.dif to perl-5.24.0.dif
* Fri Feb 12 2016 idonmez@suse.com
- Update to perl-5.22.1
  * Several bugs, including a segmentation fault, have been fixed
    with the bounds checking constructs (introduced in Perl 5.22)
  * Module::CoreList has been upgraded from version 5.20150520 to
    5.20151213.
  * PerlIO::scalar has been upgraded from version 0.22 to 0.23.
  * POSIX has been upgraded from version 1.53 to 1.53_01.
  * Storable has been upgraded from version 2.53 to 2.53_01.
  * warnings has been upgraded from version 1.32 to 1.34.
  * See perldelta.pod for all the changes.
- Update perl-5.22.0.dif stop patching CPAN.pm, it was MacOS only
  and was breaking tests (due to SHA-1 mismatch).
* Thu Jan  7 2016 bwiedemann@suse.com
- fix perl_gen_filelist macro to not fail on foo.1 man page
* Mon Dec  7 2015 opensuse@dstoecker.de
- prevent bad RPM provides for Math::BigInt and DB
  (patch file perl-5.22.0_wrong_rpm_provides.diff)
* Mon Jun 22 2015 dimstar@opensuse.org
- Reformat baselibs.conf.
* Tue Jun  9 2015 hsk@imb-jena.de
- update to perl-5.22.0
  * several new experimental features
  * new <<>> (double-diamond) operator
  * new "\b" boundaries in REs, w.r.t. Unicode
  * non-capturing RE flag "/n"
  * Unicode 7.0
  * "defined(@array)", "defined(%%hash)" are now fatal
  * unescaped literal "{" in a pattern results in deprecation warning
  * several modules updated
  * modules CGI, Module::Build no longer included
  * for a complete list of changes see perldelta.pod
- perl-5.20.0.dif changed to fit 5.22.0, and renamed to perl-5.22.0.dif
- changed patches to fit 5.22.0: perl-5.18.2-overflow.diff,
  perl-netcmdutf8.diff, perl-regexp-refoverflow.diff,
  perl-saverecontext.diff
- dropped patches (now upstream): DataDumper-no-infinite-recursion.diff,
  perl-5.20.2-Fix-Errno.pm-generation-for-gcc-5.0.patch,
  perl-5.21.8-h2ph-correct-handling-of-hex-constants-for-the-pream.patch,
  perl-5.21.8-lib-h2ph.t-to-test-generated-t-_h2ph_pre.ph-instead-.patch
* Mon Feb 23 2015 idonmez@suse.com
- Add multiple patches for gcc5 support, tracked by RT#123784
  * perl-5.20.2-Fix-Errno.pm-generation-for-gcc-5.0.patch
  * perl-5.21.8-h2ph-correct-handling-of-hex-constants-for-the-pream.patch
  * perl-5.21.8-lib-h2ph.t-to-test-generated-t-_h2ph_pre.ph-instead-.patch
* Thu Feb  5 2015 coolo@suse.com
- use rm with -f to avoid prompts for rpmbuild in terminals
* Wed Sep 17 2014 mls@suse.de
- update to perl-5.20.1
  * some performance improvements and bug fixes
  * utf8, version, File::Copy, Exporter and other modules
  have been updated
- fix infinite recursion in Data::Dumper [bnc#896715]
  new patch: DataDumper-no-infinite-recursion.diff
* Sun Jun  8 2014 coolo@suse.com
- fix some obsoletes
* Mon Jun  2 2014 mls@suse.de
- update to perl-5.20.0
  * experimental subroutine signatures
  * new slice syntax
  * experimental postfix dereferencing
  * unicode 6.3 support
  * better 64-bit support
  * do" can no longer be used to call subroutines
  * tainting now conforms to documentation
  * performance enhancements
  * multiple modules updated to current version
- perl-5.18.0.dif renamed to perl-5.20.0.dif
- dropped patches: perl-db6.diff, perl-gracefull-net-ftp.diff,
  perl-threads.t-timeout.diff
* Mon Apr  7 2014 mls@suse.de
- move English.pm into perl-base [bnc#869736]
* Tue Mar 25 2014 rguenther@suse.com
- perl-5.18.2-overflow.diff: avoid undefined overflow in S_sv_2iuv_common
* Sat Jan 18 2014 schwab@suse.de
- perl-threads.t-timeout.diff: increase timeout in t/op/threads.t
* Wed Jan  8 2014 mls@suse.de
- update to perl-5.18.2
  * updates for the B::Concise, English, File::Glob modules
  * a lexical subs regression has been fixed
  * a regression when using SUPER with AUTOLOAD has been fixed
  * a buffer overflow with very long identifiers has been fixed
  * some other minor bug fixes
- perl-reg89.diff is no longer needed
* Wed Sep  4 2013 mls@suse.de
- add libperl_requires macro
* Tue Sep  3 2013 mls@suse.de
- update to perl-5.18.1
  * B has been upgraded from 1.42 to 1.42_01
  * Digest::SHA has been upgraded from 5.84 to 5.84_01
  * Module::CoreList has been upgraded from 2.89 to 2.96
  * A number of memory leaks in regexp have been plugged
  * The debugger's man command been fixed
  * @_ is now correctly visible in the debugger
  * Lexical constants no longer crash when inlined
  * Deep recursion warnings no longer crash lexical subroutines
- backport backref fix from upstream
- fix INC containing directories multiple times
* Thu Aug  8 2013 dvaleev@suse.com
- skip itimer test from Timer-HiRes for powerpc. Build hosts
  are overloaded, building locally shows tests are passed
  (skip_time_hires.patch)
* Fri Jun 14 2013 jengelh@inai.de
- Add perl-db6.diff to bring the DB_File module up to version 1.828
  where it supports building with libdb-6.0.
* Tue Jun 11 2013 coolo@suse.com
- moving the provides of perl-macros to perl-doc so we can check
  for duplicated man pages in the gen_filelist macro
* Tue Jun 11 2013 coolo@suse.com
- obsolete perl-PathTools and other modules in core
* Thu Jun  6 2013 mls@suse.de
- update to 5.18.0
  * new handling of experimental features
  * new hash functions to improve security
  * better hash randomization
  * upgrade to Unicode 6.2
  * support for computed labels
  * vertical tabs are now whitespace
  * smartmatch is experimental again
  * lots of bug fixes
- change perl_requires macro to use MODULE_COMPAT form
* Mon May 20 2013 schwab@suse.de
- Disable testsuite only on qemu user space build
* Fri Nov 16 2012 coolo@suse.com
- update to 5.16.2
  * <Module::CoreList> has been upgraded from version 2.70 to version 2.76
  Perl 5.16.2 represents approximately 2 months of development since Perl
  5.16.1 and contains approximately 740 lines of changes across 20 files
  from 9 authors.
* Wed Nov 14 2012 opensuse@dstoecker.de
- fix version for Module::Build obsoletes, so installing newer version is possible
* Tue Sep  4 2012 coolo@suse.com
- update to 5.16.1
  * an off-by-two error in Scalar-List-Util has been fixed
  * many perl modules updated
* Tue Jun 12 2012 coolo@suse.com
- update perl-base file list
* Wed May 30 2012 coolo@suse.com
- provide a higher version for Module::Build to calm down rpm
* Wed May 23 2012 mls@suse.de
- update to 5.16.0
  * new __SUB__ token to reference current sub
  * more consistent eval
  * ties can now be weakended
  * supports (almost) unicode 6.1
  * proper supports for unicode in symbol names
  * new foldcase function fc()
  * continue no longer requires the switch feature
  * removed LinuxThreads hack for $$ and getppid
  * performance optimizations
* Mon Apr  2 2012 coolo@suse.com
- correct license statement
* Fri Jan 13 2012 mls@suse.de
- bring back NDBM_File [bnc#732929]
* Tue Oct 25 2011 mls@suse.de
- update to 5.14.2
  * calling bsd_glob with GLOB_ALTDIRFUNC no longer segfaults
  * a heap overflow in decode_xs was fixed
  * a memory leak in caller() was fixed
  * modules were updated to their latest version
  * several other bug fixes, see perldelta
* Fri Jun 17 2011 mls@suse.de
- update to 5.14.1
  - B::Deparse has been upgraded
  - Pod::Perldoc has been upgraded
  - given, when and default are now listed in perlfunc
  - multiple other doc fixes and clarifications
  - several bug fixes
* Thu May 26 2011 mls@suse.de
- backport CBuilder fix that keeps it from overwriting ccflags
  from the perl config if CCFLAGS is set in the environment
* Tue May 17 2011 mls@suse.de
- Test::Simple is actually 0.98
* Mon May 16 2011 mls@suse.de
- update to 5.14.0
  * unicode version 6.0 is now supported (mostly)
  * any unsigned value can be encoded as a character
  * some regexp enhancements, e.g. s///r option
  * array and hash container functions accept references
  * package block syntax
  * overridable tie functions
  * assignment to $0 works again
  * improved IPv6 support in the Socket module
- fix regexp crash in reg_numbered_buff_fetch [bnc#676086]
  [CVE-2010-4777]
- move unicode files from perl-doc to perl again [bnc#678877]
- remove feedback@suse.de mail address, it no longer exists
  [bnc#657625]
- support unversioned site_perl include directory
* Wed Feb 23 2011 mls@suse.de
- versionify perl-Test-Simple provides/obsoletes
* Mon Feb 14 2011 mls@suse.de
- update to perl-5.12.3 final
- remove obsolete perl-cgi-injection.diff
- remove obsolete perl-constprint.diff
* Fri Jan 28 2011 lnussel@suse.de
- Suggest instead of Recommend perl-doc. It's not useful on a
  end-user system and saves 20MB on a minimal installation.
* Fri Jan 14 2011 mls@suse.de
- update to perl-5.12.3-RC1
  * bug fix only release
  * lvalue sub return values are now COW
- fix CGI injection bugs, CVE-2010-2761, CVE-2010-4410,
  CVE-2010-4411 [bnc#657343]
* Tue Nov 30 2010 coolo@novell.com
- added a new macro %%perl_requires
* Mon Nov 29 2010 coolo@novell.com
- simplify macro logic a bit
* Mon Nov 22 2010 chris@computersalat.de
- rework process_packlist macro
  o remove .packlist, perllocal.pod file
    hence no /var/adm/perl-modules/perl-{cpan_name}
* Wed Nov 17 2010 meissner@suse.de
- increase the t/HiRes.t skew (for ppc).
* Mon Sep 27 2010 coolo@novell.com
- update to perl-5.12.2
  This release contains minor bug fixes and updates of several
  core modules, as well as minor documentation updates.
* Wed Jul 28 2010 mls@suse.de
- fix constant print issue [bnc#621856]
- fix h2ph so that _h2ph_pre.ph doesn't lead to warnings
- do not add vendorlib/auto to filelist [bnc#624628]
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Fri Jun 18 2010 mls@suse.de
- update to perl-5.12.1
  * updated CGI.pm to 3.49
  * updated Pod::Simple to 3.13
  * updated Safe to 2.27
  * fixed a couple of bugs and regressions (see perldelta)
* Mon May 24 2010 bg@novell.com
- fix for hppa [deb#543731]
* Fri May 21 2010 mls@suse.de
- also run h2ph on /usr/include/linux [bnc#603840]
* Tue Apr 13 2010 mls@suse.de
- update to perl-5.12.0 final
- move Compress::Zlib.pm back into perlpriv directory,
  moved autosplit file into it as well
* Fri Apr  9 2010 mls@suse.de
- update to perl-5.12.0-RC4
  * documentation updates
  * don't initialize end in pp_reverse when begin is NULL
  * fix eval + feature.pm + syntax error segfault
- move Compress::Zlib.pm into perlarch directory
* Sun Apr  4 2010 aj@suse.de
- Provide perl-base = pversion-release as well since this is
  required by some packages.
* Wed Mar 31 2010 mls@suse.de
- update to perl-5.12.0-RC1
  * mostly documentation updates
  * some regression fixes
* Wed Mar 24 2010 mls@suse.de
- update to perl-5.12.0-RC0
  * new ... operator
  * unicode improvements
  * "each" now also works on arrays
  * support for "delete local"
  * suidperl was dropped
* Fri Feb 12 2010 chris@computersalat.de
- fix for macros.perl
  o only add mandir if exist :)
* Thu Jan 28 2010 rguenther@suse.de
- add libbz2-devel to BuildRequires
* Sun Dec 13 2009 jengelh@medozas.de
- enable parallel building
- package documentation as noarch
* Sun Oct 25 2009 coolo@novell.com
- update to perl-5.10.1 again
* Tue Sep  8 2009 mls@suse.de
- backport upstream fixes for POSIX module to avoid clashes
  with Fcntl [bnc#446098], [bnc#515948]
- backport upstream fix for ISA assertion failure [bnc#528423]
- move unicode files from perl-doc to perl, otherwise some
  perl modules will not work
* Sat Sep  5 2009 coolo@novell.com
- revert to 5.10.0, too many problems (10 failures and 162
  cyclic dependencies for d:l:p)
* Thu Sep  3 2009 mls@suse.de
- update to perl-5.10.1 to get rid of some patches
  (the update mostly consists of changes in the
  experimental features)
* Tue Jul  7 2009 coolo@novell.com
- disable as-needed as it breaks at least make test
* Tue Jul  7 2009 coolo@novell.com
- fix macros file
* Mon Jun 29 2009 chris@computersalat.de
- spec mods
  o added lost Provides/Obsoletes perl-macros
  o cleanup tags
* Fri Jun 26 2009 chris@computersalat.de
- fix for perl_gen_filelist
  o add test for
  - f "${RPM_BUILD_ROOT}/var/adm/perl-modules/{name}"
* Fri Jun 26 2009 mls@suse.de
- add macros.perl, README.macros files contributed by
  Christian <chris@computersalat.de>
- move perl specific macros from rpm macro file to macros.perl
* Wed Jun 10 2009 mls@suse.de
- fixed off-by-one in zlib inflate code [bnc#511241]
- fixed errorcount initialization [bnc#498425]
- fixed utf8 handling in Net::Cmd [bnc#493978]
- fixed performace degradation in syslog [bnc#489114]
* Wed Jan 14 2009 mls@suse.de
- work around nroff change [bnc#463444]
- fix another rmtree vulnerability [bnc#450385]
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Nov 26 2008 mls@suse.de
- add perl-base to baselibs.conf [bnc#448884]
- include everything arch dependand in baselibs packages
* Wed Nov 19 2008 mls@suse.de
- fix ph file generation [bnc#413218]
* Fri Aug 29 2008 rguenther@suse.de
- Add Tie/Hash.pm to perl-base.  [bnc#421191]
* Mon Jul 14 2008 schwab@suse.de
- Fix another regexp backref overflow crash.
- Reenable testsuite on ppc64.
* Mon Jul 14 2008 mls@suse.de
- fix regexp backref overflow crash fix
* Fri Jul 11 2008 mls@suse.de
- fix bug File:Path that made synlink targets world-writable [bnc#402660]
- fix regexp backref overflow crash [bnc#372331]
* Tue May  6 2008 aj@suse.de
- Fix missing return value in configure script to silence rpmlint
  checks.
* Fri Apr 11 2008 mls@suse.de
- compile with -DPERL_USE_SAFE_PUTENV [bnc#377543]
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Mar 17 2008 coolo@suse.de
- fix path for generated perl bindings (bnc#371713)
* Sat Mar 15 2008 coolo@suse.de
- pod/perldiag.pod is needed in the base distribution
* Tue Mar 11 2008 coolo@suse.de
- after several discussions on how to decrease size of perl
  distribution: split out perl-doc
- preparing blacklists for temporarly autorequires
* Mon Mar 10 2008 pth@suse.de
- Fix call to dbmclose in ext/ODBM_File/ODBM_File.xs
- Run 'make check' in %%check
* Tue Feb 19 2008 mls@suse.de
- fix bug in regexp engine [bnc#355233]
* Fri Jan 18 2008 mls@suse.de
- obsolete more packages
- fix bug in enc2xs [#354424]
* Tue Jan 15 2008 schwab@suse.de
- Remove broken test.
* Mon Jan  7 2008 mls@suse.de
- update to perl-5.10.0
  * happy 20th birthday, perl!
  * many new features, e.g. say, switch, state, dor, smart match
  * regular expressions now even more convoluted
  * some modules are now in core, e.g. zlib, digest::sha
  * modules updated to current version
  * see perldelta to know all of the glorious details
* Tue Nov  6 2007 mls@suse.de
- fix buffer overflow in regex engine CVE-2007-5116 (#332199)
* Wed Oct 31 2007 dmueller@suse.de
- update rpmlintrc
* Fri May 25 2007 ro@suse.de
- added rpmlintrc: ignore some devel files in perl package
* Mon May 21 2007 rguenther@suse.de
- Include Config_heavy.pl in perl-base.
* Fri May 11 2007 rguenther@suse.de
- Add all required directories to perl-base.
* Mon Apr 23 2007 rguenther@suse.de
- Split off a perl-base package containing /usr/bin/perl and
  some basic modules.
- Depend on perl-base from perl.
* Mon Mar 26 2007 rguenther@suse.de
- Add gdbm-devel, ncurses-devel and zlib-devel BuildRequires.
* Wed Dec 27 2006 schwab@suse.de
- Fix makedepend.
* Wed Dec 20 2006 jw@suse.de
- graceful-net-ftp patch added.
  Lousy FTP server responses could trigger silly error messages in Net::FTP
  and had no usable status_line in LWP.
  Now it is 500 + whatever message the server responded.
* Fri Feb 17 2006 mls@suse.de
- suppress prototype warning in autouse [#151459]
* Wed Feb  1 2006 mls@suse.de
- update to perl-5.8.8
- enable use64bitint on ppc/ppc64
* Sun Jan 29 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 28 2006 mls@suse.de
- update to perl-5.8.8-RC1
* Fri Dec  9 2005 mls@suse.de
- fix sprintf format string issues CVE-2005-3962 (#136360)
- added workaround for hanging debugger (#135559)
- moved SuSEconfig script to /usr/lib/perl5 (#130762)
* Tue Sep  6 2005 mls@suse.de
- fix infinite warn recursion by backporting change from bleadperl
  [#115402]
* Thu Aug 18 2005 mls@suse.de
- remove postun, handle it with ghosts
* Thu Jul 28 2005 mls@suse.de
- deal with new Config_heavy.pl
* Mon Jul 25 2005 mls@suse.de
- add rmtree patch (CAN-2005-0448)
* Fri Jul 22 2005 lmuelle@suse.de
- update to perl-5.8.7
* Wed Apr  6 2005 meissner@suse.de
- moved # icecream 0 tag where it does not get removed by checkin.
* Wed Apr  6 2005 meissner@suse.de
- Disable icecream to avoid problem with gcc4 / libperl.so preload.
* Thu Mar 24 2005 uli@suse.de
- fixed to build on ARM
* Fri Feb 18 2005 mls@suse.de
- fix perlbug mail sending
* Thu Feb 17 2005 mls@suse.de
- fix broken :encoding(utf8)
* Fri Feb  4 2005 mls@suse.de
- fix CAN-2005-0155/CAN-2005-0156 (PERLIO_DEBUG)
- fix CAN-2004-0452 (File::Path::rmtree)
* Mon Nov 29 2004 mls@suse.de
- update to perl-5.8.6
* Thu Aug 26 2004 schwab@suse.de
- Remove gratuitous use of kernel header.
- Fix mkdir race.
* Wed Jul 28 2004 mls@suse.de
- update to perl-5.8.5
* Tue Mar 16 2004 mls@suse.de
- fix instmodsh tmp file usage
* Fri Feb 27 2004 mls@suse.de
- update to perl-5.8.3
* Mon Dec  8 2003 mls@suse.de
- fix setenv issue by making perl behave differently if used
  embedded in an application (turns on PERL_USE_SAFE_PUTENV).
  [#32548]
* Sun Nov  2 2003 adrian@suse.de
- add missing Requires for gzip (used in SuSEconfig.perl)
- make it possible to build as non-root
* Mon Oct  6 2003 mls@suse.de
- update to perl-5.8.1
- fix srand initialization problem [perl change #21397]
* Mon Sep 22 2003 mls@suse.de
- update to perl-5.8.1-RC5
* Fri Aug 22 2003 mls@suse.de
- update to perl-5.8.1-RC4
- added sysconfig metadata
- use /usr/lib/perl* in the filelist so /usr/lib/debug doesn't get
  picked up
* Thu Aug 21 2003 mjancar@suse.cz
- use $RPM_OPT_FLAGS
* Fri Aug  1 2003 mls@suse.de
- fixed perlcc
* Thu Jul 31 2003 mls@suse.de
- update to perl-5.8.1-RC3
* Mon Jul 14 2003 mls@suse.de
- MM_Unix: fix vendor/siteman default path
* Fri Jul 11 2003 mls@suse.de
- create auto dirs in vendor_perl
* Fri Jul 11 2003 mls@suse.de
- update to perl-5.8.1-RC2
- use buildroot
* Wed Jun 11 2003 kukuk@suse.de
- Add auto subdirectory for perl modules
* Fri May  9 2003 ro@suse.de
- fix build with db-4.1
* Thu Feb  6 2003 mls@suse.de
- add sysconfig metadata to sysconfig.suseconfig-perl
- fix memory leak in socket creation
- restart stdio read/write when receiving EINTR
* Thu Jan  9 2003 mls@suse.de
- link with -lgdbm_compat when building ODBM_File
* Tue Sep 17 2002 ro@suse.de
- get all ph-files for bi-arch platforms
* Tue Sep 17 2002 mls@suse.de
- work around a bug in .ph file generation (#19664)
* Mon Sep  9 2002 mls@suse.de
- fix permissions of libperl.so
- added missing enc2xs binary
- create more .ph header files
- fixed h2ph enum handling
- (fixes bug #19175)
* Fri Aug 23 2002 mls@suse.de
- Fix bug in conversion of literals to floating point
- Add workaround for glibc crypt_r() bug
* Fri Aug  9 2002 mls@suse.de
- fix libs to include pthreads if threads are selected and
  /lib64/libc.so.6 exists
* Thu Aug  8 2002 mls@suse.de
- enabled thread support
* Wed Aug  7 2002 mls@suse.de
- corrected file list, added obsolete entries also to provides
* Wed Jul 31 2002 mls@suse.de
- Added Obsoletes line to obsolete all modules now packed
  with the core perl
* Fri Jul 26 2002 kukuk@suse.de
- Add a Provide "perl-base" [Bug #17259]
* Tue Jul 23 2002 mls@suse.de
- Allow missing tests in 'make test'
- delete broken lib/File/Find/t/find.t test
* Tue Jul 23 2002 mls@suse.de
- MM_Unix.pm: use INSTALLARCHLIB instead of INSTALLSITEARCH to
  store the site perllocal.pod file, like the printed message says
- added missing man3 pages
* Mon Jul 22 2002 mls@suse.de
- MM_Unix.pm: allow to overwrite PREFIX in the makefile, use
  better default for installsiteman{1,3}dir
* Fri Jul 19 2002 mls@suse.de
- update to perl-5.8.0
* Fri Jul  5 2002 kukuk@suse.de
- Use %%ix86 macro
* Tue Jun 18 2002 uli@suse.de
- disable check on armv4l
* Mon Jun 10 2002 mls@suse.de
- Pod::Man: don't put the generation date in the man pages
* Thu Jun  6 2002 olh@suse.de
- disable make check on ppc64, enable lfs test on ppc
* Thu Mar 14 2002 mls@suse.de
- Allow XSUBs as AUTOLOAD functions, worked in 5.6.0, needed
  for perl-Qt
* Fri Feb 22 2002 mls@suse.de
- Fixed File::Find if no_chdir is set (Ticket 20020213990000277)
* Wed Feb 20 2002 mls@suse.de
- Build DynaLoader.a with -fPIC to make mod_perl work on s390x
* Wed Feb  6 2002 coolo@suse.de
- patch Configure to also use -fPIC on Linux - prevents crashes on
  s390x
- ported over the hints patch from 7.2-lib64
* Tue Feb  5 2002 mls@suse.de
- Use Config.pm of libperl.so build, so that apps use the right
  link options.
* Mon Feb  4 2002 mls@suse.de
- Added generation of libperl.so
* Thu Jan 24 2002 schwab@suse.de
- Fix h2ph for gcc 3.
* Mon Jan 14 2002 mls@suse.de
- Moved rc.config variable to sysconfig/suseconfig
* Mon Jan  7 2002 schwab@suse.de
- Fix dependency generation for gcc 3.1 again.
* Thu Dec  6 2001 schwab@suse.de
- Don't add /usr/local/lib and /usr/local/include to the search paths.
- Fix dependency generation for gcc 3.1.
* Tue Nov 20 2001 schwab@suse.de
- Don't generate h2ph, h2xs, pod2man manpages by hand.
* Thu Sep 27 2001 mls@suse.de
- Fixed generation of perllocal.pod, also create perllocal.3pm
* Wed Sep 12 2001 mls@suse.de
- Fixed h2ph macro expansion/redefinition bugs.
- Moved *.ph creation from SuSEconfig to spec file.
* Fri Aug 31 2001 schwab@suse.de
- Remove ia64 workarounds.
* Wed Jun 20 2001 mls@suse.de
- bzip2 source
* Wed Jun 20 2001 mls@suse.de
- Update to perl-5.6.1
- Merged linux-alpha.sh and linux-sparc.sh into linux.sh
- axp compiler workaround: add -mieee
- use /lib64:/usr/lib64 on sparc64
* Mon Jun 11 2001 schwab@suse.de
- Remove ElectricFence from neededforbuild (got added by accident).
* Fri Apr 13 2001 schwab@suse.de
- Build with -O0 on ia64.
* Mon Mar 26 2001 schwab@suse.de
- Fix equality operator for systems that don't have NV_PRESERVES_UV.
- Reenable some tests on ia64.
* Thu Feb 22 2001 schwab@suse.de
- Fix POSIX module.
* Tue Dec  5 2000 schwab@suse.de
- Disable some problematic tests on ia64.
- Merge ia64 configuration with generic linux.
* Thu Oct 26 2000 ro@suse.de
- use new db for DB_File
- perl binary is no longer linked to any db lib
* Tue Oct 10 2000 ro@suse.de
- Config.pm: set $perl to 'perl'
- bzipped sources
- added some mandir patches
* Mon Sep 25 2000 ro@suse.de
- no test for lfs on ppc
* Wed Aug 16 2000 ro@suse.de
- update to 5.6.0
* Tue Aug 15 2000 ro@suse.de
- Security fix (/bin/mail+suidperl) added (from draht@suse.de)
* Fri Jul 14 2000 kukuk@suse.de
- Add license information and group tag (Bug #3454)
* Tue Jul 11 2000 ro@suse.de
- make perllocal.SuSE script more flexible
* Sat Apr  1 2000 bk@suse.de
- some tests don't pass on s390 too, known.
* Fri Mar  3 2000 schwab@suse.de
- Add support for ia64.
* Wed Jan 19 2000 ro@suse.de
- man -> /usr/share/man ; affects all perl packages
* Tue Dec 14 1999 kukuk@suse.de
- Fixed for SPARC
* Tue Nov  2 1999 ro@suse.de
- do h2ph for stdarg and stddef (BUG#785)
* Mon Oct 18 1999 ro@suse.de
- don't print error if /usr/src/linux is not owned by a package
  (BUG#215)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 27 1999 ro@suse.de
- added "gnu","net" and "rpc" to directories for h2ph
* Thu Jul  8 1999 ro@suse.de
- added "bits" to directories for h2ph (closing BUG 58)
* Thu Jul  8 1999 ro@suse.de
- fix for perldoc
- update to 5.005_03
* Mon Mar  1 1999 ro@suse.de
- t/lib/anydbm: removed test 12 : create empty record: invalid for db2
* Thu Jan  7 1999 ro@suse.de
- alpha changes ; dont "make test" on alpha for now :-(
* Mon Nov 16 1998 ro@suse.de
- update to 5.00502
- fixed manpages for h2ph, h2xs, pod2man
- use configure.gnu
- keep SuSEconfig.perl from using more time than needed
* Fri Aug 28 1998 ro@suse.de
- updated to version perl5.004_05-MAINT_TRIAL_5
- updated filelist
- temporarily disablet test op/group.t for nobody/nogroup problem
* Wed Aug 19 1998 ro@suse.de
- added security-patches for pstruct and perldoc
* Fri Jul 24 1998 bs@suse.de
- enabled bincompat3
* Thu Jul  9 1998 ro@suse.de
- added some security and glib-patches (doio.c, perl.c)
- re-added support for gdbm
* Mon Jul  6 1998 ro@suse.de
- added rc.config.perl with variables:
    CREATE_PERLLOCAL_POD="yes"
    GENERATE_PERL_SYSTEM_INCLUDES="yes"
* Mon Jul  6 1998 ro@suse.de
- added SuSEconfig.perl and perllocal.SuSE
  + check if kernel-sources have changed and call h2ph
  + check installed modules and add/delete entries in perllocal.pod
* Thu Jan 22 1998 florian@suse.de
- use a fixed path as architecture name
* Tue Nov 11 1997 florian@suse.de
- fixed file list
- update to perl 5.004_04
* Tue Oct 14 1997 ro@suse.de
- ready for autobuild
  updated file list
* Thu Oct  9 1997 florian@suse.de
- prepare for autobuild
* Tue May 20 1997 florian@suse.de
- update to version 5.004
- disable hooks to csh in perl, it is not installed on all systems
* Thu Jan  2 1997 bs@suse.de
  h2ph call in doinst.sh added.
* Thu Jan  2 1997 florian@suse.de
  update to version 5.003
  security fix for suidperl
